#
# spec file for package lsyncd
#
# Copyright (c) 2017 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


#Compat macro for new _fillupdir macro introduced in Nov 2017
%if ! %{defined _fillupdir}
  %define _fillupdir /var/adm/fillup-templates
%endif

%if 0%{?suse_version} > 1230
%bcond_without systemd
%else
%bcond_with    systemd
%endif

Name:           lsyncd
Version:        2.1.5
Release:        9.3.1
Url:            http://code.google.com/p/lsyncd/
Source0:        http://lsyncd.googlecode.com/files/%{name}-%{version}.tar.gz
Source1:        %{name}-init.d
Source2:        %{name}.conf
Source3:        rsync_sudo.sh
Source4:        %{name}.service
Source5:        %{name}.sysconfig
Source6:        %{name}.logrotate
Patch0:         lsyncd-lua-5_3.patch
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildRequires:  asciidoc
BuildRequires:  automake
BuildRequires:  lua-devel >= 5.1
BuildRequires:  pkg-config
%if %{with systemd}
%{?systemd_requires}
BuildRequires:  systemd-rpm-macros
%else
PreReq:         %insserv_prereq 
%endif
PreReq:         %fillup_prereq
Requires:       rsync
Summary:        Live Syncing (Mirror) Daemon
License:        GPL-2.0
Group:          Productivity/Networking/Other

%description
Lsyncd (Live Syncing (Mirror) Daemon) uses rsync to synchronize local directories with a remote machine running rsyncd. It watches multiple directory trees through inotify. The first step after adding the watches is to rsync all directories with the remote host, and then the software synchronizes single files by collecting the inotify events. lsyncd is a lightweight live mirror solution that should be easy to install and use while blending well with your system.

%prep
%setup -q
if pkg-config --atleast-version=5.3 lua; then
%patch0 -p1
fi

%build
autoreconf -fiv
export CFLAGS="%optflags"
export LIBLUA_LIBS=$(pkg-config --libs lua)
export LIBLUA_CFLAGS=$(pkg-config --cflags lua)
%configure --docdir=%{_docdir}/%{name}
%__make %{?jobs:-j%jobs}

%install
%makeinstall
%{__mkdir_p} %{buildroot}%{_sbindir}
%{__mkdir_p} %{buildroot}%{_sysconfdir}/%{name}
%{__mkdir_p} %{buildroot}%{_localstatedir}/log/lsyncd
%if %{with systemd}
%__install -Dm 755 %{S:4} %{buildroot}%{_unitdir}/lsyncd.service
ln -s /usr/sbin/service %{buildroot}%{_sbindir}/rc%{name}
%__install -Dm 644 %{S:6} %{buildroot}%{_sysconfdir}/logrotate.d/lsyncd
%else
%__install -Dm 755 %{S:1} %{buildroot}%{_initrddir}/lsyncd
ln -fs %{_sysconfdir}/init.d/lsyncd %{buildroot}%{_sbindir}/rc%{name}
%endif
%__install -Dm 755 %{S:2} %{buildroot}%{_sysconfdir}/lsyncd/lsyncd.conf
%__install -Dm 755 %{S:3} %{buildroot}%{_sysconfdir}/lsyncd/rsync_sudo.sh
%__install -Dm 644 %{S:5} %{buildroot}%{_fillupdir}/sysconfig.%{name}

%if %{with systemd}
%pre
%service_add_pre lsyncd.service
%endif

%post
%if %{with systemd}
%service_add_post lsyncd.service
%{fillup_only}
%else
%{fillup_and_insserv}
%endif

%if %{with systemd}
%preun
%service_del_preun lsyncd.service
%endif

%postun
%if %{with systemd}
%service_del_postun lsyncd.service
%else
%{restart_on_update}
%{insserv_cleanup}
%endif

%files
%defattr(-,root,root)
%doc ChangeLog COPYING
%doc %{_defaultdocdir}/%{name}/
%{_bindir}/lsyncd
%{_mandir}/man1/lsyncd.1.gz
%if %{with systemd}
%{_unitdir}/lsyncd.service
%{_sysconfdir}/logrotate.d/lsyncd
%else
%{_initrddir}/lsyncd
%endif
%{_sbindir}/rc%{name}
%dir %{_sysconfdir}/%{name}
%config(noreplace) %{_sysconfdir}/%{name}/lsyncd.conf
%config(noreplace) %{_sysconfdir}/%{name}/rsync_sudo.sh
%dir %{_localstatedir}/log/%{name}
%{_fillupdir}/sysconfig.%{name}

%changelog
* Tue Apr 17 2018 mikhail.kasimov@gmail.com
- Updated path to lsyncd.conf for lsyncd.service and lsyncd.sysconfig
  (boo#975118)
* Thu Nov 23 2017 rbrown@suse.com
- Replace references to /var/adm/fillup-templates with new
  %%_fillupdir macro (boo#1069468)
* Wed Mar 15 2017 dimstar@opensuse.org
- Explicitly package files installed by make install into _docdir:
  rpm 4.13 no longer implicitly packages those files.
* Thu Jul 30 2015 dimstar@opensuse.org
- Add lsyncd-lua-5_3.patch: Fix build with LUA 5.3.
* Fri Jun  5 2015 p.drouand@gmail.com
- Remove scriptlets pre/post on systems with sysvinit support.
* Sun Mar  1 2015 p.drouand@gmail.com
- Update to version 2.1.5
  * enhancement: Added rsync options: bwlimit, timeout
  * fix: Specifying ssh port no longer overwrites the last rsync option
  * fix: rsync option password_file is now accepted
  * fix: onAttrib is accepted again
  * fix: -log Exec now prints now fully all arguments
  * fix: configure script lua detection now includes math lib to workaround
    wrongly created "needs COMPAT_ALL" messages.
  * fix: repaired variable replacement for layer 3 scripts
  * fix: config.delay is now checked to a number >= 0
  * change: a2x is no longer checked by configure script. should not be
    needed when building from tarball
- Use download Url as source
- Add sysconfig config script support for init scripts
- Fix sysvinit script to be able to use sysconfig options
- Add systemd support for openSUSE > 13.2
- Add required macros to support correctly sysvinit script
- Remove redundant %%clean section
* Wed Feb  6 2013 e.istomin@edss.ee
- update to 2.1.4
- remove lua 5.2 patch (https://github.com/axkibe/lsyncd/pull/148)
* Tue Oct  9 2012 crrodriguez@opensuse.org
- Build against LUA 5.2
* Sun Feb 26 2012 dmueller@suse.de
- fix build in factory (build against lua 5.1)
* Mon Nov 28 2011 eugene.istomin@edss.ee
- update to 2.0.5
  * fix: Lsyncd will now terminate if it inotify watching exceeds
    its preset limit.
  * fix: rsync error exit code 12 now results in retries.
  * fix: Lsyncd 2.0.5 should now compile better on a bit elder
    GNU/Linux versions.
  * fix: examples are now installed in the configured document directory.
  * fix: partial transfers during startup are considered ok. Lsyncd
    will rework the specified files anyway.
  * change: Layer 1 interface init() now receives an "Init" event
    instead of an inlet.
  * change: builtin Lua code is now loaded via a c-array.Now more
    portable and correct memory flags are set.
  * change: Lsyncd will now bail on unknown error codes.
  * enhancement: settings.maxProcesses can now be set as a global limit of childprocesses
  * enhancement: Lsyncd will refuse to start when any startup rsync
    does not work cleanly and returns "again" unless settings.insist or
  - -insist is specified, then Lsyncd will keep retrying until it works.
  * enhancement: option "rsyncBinary" determines which rsync Lsyncd calls.
    Default is "/usr/bin/rsync"
  * enhancement: fsevents ("inotify for OSX") fixed for Snowleopard.
    and is available to configure by default.
  * enhancement: settings.inotifyMode: the actualy Modification event
    Lsyncd reacts to can now be configured. Default is to react on
    file closing in write mode.
  * enhancement: readdir(path) is available to userscripts, reads the contents
    of a directory.
* Mon Mar 28 2011 dmacvicar@suse.de
- update to 2.0.4
  * enhancement: new setting options logident, logfacility
  * fix: moving filenames with spaces through ssh
  * fix: excludes containing chars %% $ ( ) . [ ] + -
  * fix: various typos
  * change: api, settings.statusInterval instead of
  settings.statusIntervall
* Tue Mar  8 2011 dmacvicar@suse.de
- update to 2.0.3
  * enhancement: new default target --direct using /bin/ binaries
    to keep to local dirs in sync (and by default
    not preserving ownership)
  * example: added a new example how to remotely execute a command
    after each rsync operations
  * fix: possible crash with long rsyncOps table exceeding lua stack.
  * fix: excludes now properly match relative and absolute paths
  * fix: call to nil function when manually adding blanket delays
  * fix: on ReiserFS not delivering proper dir stats and when
    encountering a symlink, aquire the node stat for the symlink
    instead from the linked node.
  * change: leave lua apichecking enabled by default.
* Fri Jan 21 2011 dmacvicar@suse.de
- update to 2.0.2
  * fix: exclude rules not terminated with '/' now match a file or dir
  named exactly the same not starting with.
  * fix: pass exclude rules to the startup sync
  * fix: when matching exclusion to not add inotify use same partial path
    than on syncs
  * fix: properly close pipes that needed more than one write.
- 2.0.1 changes
  * most important fix: The garbage collector in 2.0.0 was able to
    remove event lists just at the wrong moment so an "agent unknown"
    error was raised.
  * fixed: The pid in the pidfile should be now the pid after the deamon
    fork() and not the pid initiators pid.
  * improved: You can now specify multiple command-line options in
    rsyncOps by using a table. eg. rsyncOps = {"--lts", "--safe-links"}
* Thu Dec  2 2010 dmacvicar@suse.de
- update to 2.0.0 final
* Fri Nov 26 2010 dmacvicar@suse.de
- update to 2.0beta3
